# Cloud Platform Examples

Examples for working with major cloud data platforms.

## Available Examples

- databricks/unity_catalog/ - Unity Catalog + Delta
- fabric/lakedb/ - Fabric LakeDB
- azure_synapse/ - Azure Synapse Analytics
- snowflake/ - Snowflake
- bigquery/ - BigQuery

## Quick Start

Open the notebooks:

- databricks/unity_catalog/unity_catalog_example.ipynb
- fabric/lakedb/fabric_lakedb_example.ipynb
- azure_synapse/synapse_analytics_example.ipynb
- snowflake/snowflake_demo.ipynb
- bigquery/bigquery_demo.ipynb
